==> doctorlink-design-system-1.1.2.tgz: package/es/Components/Link/UnderlinedLink.js <==
import React from 'react';
import PropTypes from 'prop-types';
import { css } from 'styled-components';
import * as reset from '../reset';
import colors from '../../Tokens/base/colors';

const regularStyle = css`
  font-size: ${p => p.theme.text.body.fontSize}px;
  line-height: ${p => p.theme.text.body.lineHeight}px;
`;

const largeStyle = css`
  font-size: ${p => p.theme.text.navigation.fontSize}px;
  line-height: ${p => p.theme.text.navigation.lineHeight}px;
`;
export const UnderlinedLinkContainer = props => React.createElement(
  UnderlinedLinkComponent,
  null,
  React.createElement(Text, props),
  props.variation !== 'large' && React.createElement(Line, { variation: props.variation, color: props.borderColor })
);

UnderlinedLinkContainer.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Underline color if underlined
   */
  borderColor: PropTypes.string,
  /**
   * Label
   */
  children: PropTypes.node.isRequired,
  /**
   * Regular or small UnderlinedLink.
   */
  variation: PropTypes.oneOf(['large', 'regular'])
} : {};

const Text = reset.div`
  display: inline-block;
  padding-bottom: ${p => p.theme.spacing.gap}px;
  ${props => props.variation === 'large' ? largeStyle : regularStyle}
  ${p => p.variation === 'large' && `border-bottom: 1px solid ${p.borderColor};`}
`;

const Line = reset.div`
  width: ${p => p.variation === 'large' ? '100%' : '54px'};
  height: 1px;
  background-color: ${p => p.color};
`;

const UnderlinedLinkComponent = reset.div`
  font-family: ${p => p.theme.text.fontFamily};
  margin-top: ${p => p.theme.spacing.marginVertical * 2}px;
  margin-bottom: ${p => p.theme.spacing.marginVertical * 2}px;
  color: ${p => p.theme.text.color};
  display: block;
  ${props => props.variation === 'large' ? largeStyle : regularStyle}
`;

const UnderlinedLink = props => React.createElement(UnderlinedLinkContainer, props);

UnderlinedLink.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Underline color if underlined
   */
  borderColor: PropTypes.string,
  /**
   * Label
   */
  children: PropTypes.node.isRequired,
  /**
   * Regular or small UnderlinedLink.
   */
  variation: PropTypes.oneOf(['large', 'regular'])
} : {};

UnderlinedLink.defaultProps = {
  variation: 'regular',
  noWrap: false,
  align: 'inherit',
  wholeLine: false,
  borderColor: colors.brand100
};

export default UnderlinedLink;

==> doctorlink-design-system-1.1.6.tgz: package/es/Components/Link/UnderlinedLink.js <==
import React from 'react';
import PropTypes from 'prop-types';
import { css } from 'styled-components';
import * as reset from '../reset';
import colors from '../../Tokens/base/colors';

const regularStyle = css`
  font-size: ${p => p.theme.text.body.fontSize}px;
  line-height: ${p => p.theme.text.body.lineHeight}px;
`;

const largeStyle = css`
  font-size: ${p => p.theme.text.navigation.fontSize}px;
  line-height: ${p => p.theme.text.navigation.lineHeight}px;
`;
export const UnderlinedLinkContainer = props => React.createElement(
  UnderlinedLinkComponent,
  null,
  React.createElement(Text, props),
  props.variation !== 'large' && React.createElement(Line, { variation: props.variation, color: props.borderColor })
);

UnderlinedLinkContainer.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Underline color if underlined
   */
  borderColor: PropTypes.string,
  /**
   * Label
   */
  children: PropTypes.node.isRequired,
  /**
   * Regular or small UnderlinedLink.
   */
  variation: PropTypes.oneOf(['large', 'regular'])
} : {};

const Text = reset.div`
  display: inline-block;
  padding-bottom: ${p => p.theme.spacing.gap}px;
  ${props => props.variation === 'large' ? largeStyle : regularStyle}
  ${p => p.variation === 'large' && `border-bottom: 1px solid ${p.borderColor};`}
`;

const Line = reset.div`
  width: ${p => p.variation === 'large' ? '100%' : '54px'};
  height: 1px;
  background-color: ${p => p.color};
`;

const UnderlinedLinkComponent = reset.div`
  font-family: ${p => p.theme.text.fontFamily};
  margin-top: ${p => p.theme.spacing.marginVertical}px;
  margin-bottom: ${p => p.theme.spacing.marginVertical}px;
  color: ${p => p.theme.text.color};
  display: block;
  ${props => props.variation === 'large' ? largeStyle : regularStyle}
`;

const UnderlinedLink = props => React.createElement(UnderlinedLinkContainer, props);

UnderlinedLink.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Underline color if underlined
   */
  borderColor: PropTypes.string,
  /**
   * Label
   */
  children: PropTypes.node.isRequired,
  /**
   * Regular or small UnderlinedLink.
   */
  variation: PropTypes.oneOf(['large', 'regular'])
} : {};

UnderlinedLink.defaultProps = {
  variation: 'regular',
  noWrap: false,
  align: 'inherit',
  wholeLine: false,
  borderColor: colors.brand100
};

export default UnderlinedLink;
